from ipywidgets import Dropdown, VBox, Select, Layout, Label
import functools
import pandas as pd

from lhcsmapi.gui.BaseModule import BaseModule


class HwcBrowser(BaseModule):
    def __init__(self, circuit_type, hwc_test):
        self.circuit_type = circuit_type
        self.hwc_test = hwc_test

        hwc_test_history_df = pd.read_csv('/eos/project/l/lhcsm/hwc/rb/hwc_test_history.csv')
        self.hwc_sel_test_df = hwc_test_history_df[hwc_test_history_df['Test'] == self.hwc_test]

        unique_circuits = self.hwc_sel_test_df['Circuit'].unique()
        self.select_circuit_name_dropdown = Dropdown(
            options=unique_circuits,
            description='Circuit name:',
            disabled=False,
        )
        self.select_circuit_name_dropdown.observe(functools.partial(HwcBrowser.handle_sel_cir_event, self=self),
                                                  names='value')

        self.hwc_desc = Label(value='\t|\t'.join(self.hwc_sel_test_df.columns.values))

        self.hwc_sel_test_sel_circuit_df = self.hwc_sel_test_df[self.hwc_sel_test_df['Circuit'] == unique_circuits[0]]

        lst = HwcBrowser.convert_to_list(self.hwc_sel_test_sel_circuit_df)

        self.hwc_sel = Select(
            options=lst,
            rows=10,
            disabled=False,
            layout=Layout(display="flex", flex_flow='column', width='100%')
        )

        self.widget = VBox(children=[self.select_circuit_name_dropdown, self.hwc_desc, self.hwc_sel])

    def handle_sel_cir_event(b, self):
        sel_circuit = self.select_circuit_name_dropdown.value
        self.hwc_sel_test_sel_circuit_df = self.hwc_sel_test_df[self.hwc_sel_test_df['Circuit'] == sel_circuit]
        lst = HwcBrowser.convert_to_list(self.hwc_sel_test_sel_circuit_df)
        self.hwc_sel.options = lst

    @staticmethod
    def convert_to_list(hwc_sel_test_sel_circuit_df):
        output_list = []
        for index, row in hwc_sel_test_sel_circuit_df.iterrows():
            output_list.append('\t|\t'.join(row.values.tolist()))
        return output_list

    def get_sel_row(self):
        return self.hwc_sel_test_sel_circuit_df[
            self.hwc_sel_test_sel_circuit_df.index == self.hwc_sel_test_sel_circuit_df.index[self.hwc_sel.index]]

    def get_circuit_name(self):
        sel_row = self.get_sel_row()
        return sel_row['Circuit'].values[0]

    def get_start_time(self):
        sel_row = self.get_sel_row()
        return sel_row['Start'].values[0]

    def get_end_time(self):
        sel_row = self.get_sel_row()
        return sel_row['End'].values[0]
